
.. |copy|   unicode:: U+000A9 .. COPYRIGHT SIGN

.. image:: https://img.shields.io/github/license/sdss/mangadap
   :target: https://github.com/sdss/mangadap/blob/master/LICENSE.md
   :alt: License

Copyright |copy| 2019, SDSS-IV/MaNGA Pipeline Group


